@@ -1,6 +1,6 @@
 ;;; password-cache.el --- Read passwords, possibly using a password cache.
 
-;; Copyright (C) 1999-2000, 2003-2012  Free Software Foundation, Inc.
+;; Copyright (C) 1999-2000, 2003-2014 Free Software Foundation, Inc.
 
 ;; Author: Simon Josefsson <simon@josefsson.org>
 ;; Created: 2003-12-21
@@ -102,13 +102,12 @@ Warning: the password is cached without checking that it is
 correct.  It is better to check the password before caching.  If
 you must use this function, take care to check passwords and
 remove incorrect ones from the cache."
+  (declare (obsolete password-read "23.1"))
   (let ((password (password-read prompt key)))
     (when (and password key)
       (password-cache-add key password))
     password))
 
-(make-obsolete 'password-read-and-add 'password-read "23.1")
-
 (defun password-cache-remove (key)
   "Remove password indexed by KEY from password cache.
 This is typically run by a timer setup from `password-cache-add',
